@@ -1,6 +1,6 @@
 package App::norepeat;
 
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 1;
 # ABSTRACT: Run commands, but not repeatedly
@@ -17,12 +17,16 @@ App::norepeat - Run commands, but not repeatedly
 
 =head1 VERSION
 
-This document describes version 0.04 of App::norepeat (from Perl distribution App-norepeat), released on 2014-10-07.
+This document describes version 0.05 of App::norepeat (from Perl distribution App-norepeat), released on 2015-05-16.
 
 =head1 SYNOPSIS
 
 See the command-line script L<norepeat>.
 
+=head1 SEE ALSO
+
+L<Sub::NoRepeat>
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/App-norepeat>.
@@ -45,7 +49,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
